pub fn compile_to_object(ir_code: &str, output: &str) -> CodegenResult<()>Expand description
Compile LLVM IR to object file without linking
This is useful for testing IR generation without needing a complete program with main()
pub fn compile_to_object(ir_code: &str, output: &str) -> CodegenResult<()>Compile LLVM IR to object file without linking
This is useful for testing IR generation without needing a complete program with main()